summaryrefslogtreecommitdiffstats
path: root/reporting/functest
diff options
context:
space:
mode:
Diffstat (limited to 'reporting/functest')
-rwxr-xr-xreporting/functest/reporting-status.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/reporting/functest/reporting-status.py b/reporting/functest/reporting-status.py
index 69be20e..95f9e66 100755
--- a/reporting/functest/reporting-status.py
+++ b/reporting/functest/reporting-status.py
@@ -28,9 +28,9 @@ testValid = []
otherTestCases = []
reportingDate = datetime.datetime.now().strftime("%Y-%m-%d %H:%M")
-# init just snaps_health_check to get the list of scenarios
-# as all the scenarios run snaps_health_check
-snaps_health_check = tc.TestCase("snaps_health_check", "functest", -1)
+# init just connection_check to get the list of scenarios
+# as all the scenarios run connection_check
+healthcheck = tc.TestCase("connection_check", "functest", -1)
# Retrieve the Functest configuration to detect which tests are relevant
# according to the installer, scenario
@@ -92,7 +92,7 @@ for version in versions:
# For all the installers
for installer in installers:
# get scenarios
- scenario_results = rp_utils.getScenarios(snaps_health_check,
+ scenario_results = rp_utils.getScenarios(healthcheck,
installer,
version)
scenario_stats = rp_utils.getScenarioStats(scenario_results)